@@ -1,4 +1,4 @@
-//$Id: main.cc,v 1.1 2002/02/19 19:55:55 murrayc Exp $ -*- c++ -*-
+//$Id: main.cc 2 2003-01-21 13:41:59Z murrayc $ -*- c++ -*-
 
 /* gtkmm example Copyright (C) 2002 gtkmm development team
  *
@@ -24,7 +24,7 @@ int main (int argc, char *argv[])
   Gtk::Main kit(argc, argv);
 
   HelloWorld helloworld;
-  kit.run(helloworld); //Shows the window and returns when it is closed.
+  Gtk::Main::run(helloworld); //Shows the window and returns when it is closed.
 
   return 0;
 }
